#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MADD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MADD_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/madd.hpp>

#endif
